@@ -1,4 +1,4 @@
-#!/bin/sh
+#!/bin/sh -v
 
 set -e
 
@@ -6,6 +6,7 @@ aclocal
 autoheader
 touch stamp-h
 autoconf
+libtoolize --copy --force --automake
 automake -a -c
 glib-gettextize --copy --force
 intltoolize --automake --copy --force
