@@ -197,14 +197,14 @@ static void
 halt(GtkWidget * widget, gpointer data)
 {
     GError **error = NULL;
-    g_spawn_command_line_async("/sbin/poweroff -fp", error);
+    g_spawn_command_line_async("/sbin/poweroff", error);
 }
 
 static void
 reboot(GtkWidget * widget, gpointer data)
 {
     GError **error = NULL;
-    g_spawn_command_line_async("/sbin/reboot -fp", error);
+    g_spawn_command_line_async("/sbin/reboot", error);
 }
 
 gboolean
