@@ -27,13 +27,12 @@
 
 #define _GNU_SOURCE
 
-#include <stdio.h>
-#include <unistd.h>
-#include <stdlib.h>
-#include <gtk/gtk.h>
-#include <glib.h>
-#include <string.h>
 #include <glib/gi18n.h>
+#include <glib.h>
+#include <gtk/gtk.h>
+#include <stdio.h>
+#include <stdlib.h>
+#include <string.h>
 
 #include <greeter.h>
 
@@ -68,10 +67,7 @@ update_selected_sess()
         ldminfo *curr_host = NULL;
         GList *s = NULL;
 
-        curr_host =
-            g_hash_table_lookup(ldminfo_hash,
-                                g_list_nth_data(host_list,
-                                                selected_host_id));
+        curr_host = ldminfo_lookup(g_list_nth_data(host_list, selected_host_id));
         s = curr_host->sessions;
         g_strlcpy(session, g_list_nth_data(s, sess_selected - 2),
                   MAXSTRSZ);
@@ -99,13 +95,11 @@ sesswin(GtkWidget * widget, GtkWindow * win)
 
     sess_select = gtk_combo_box_new_text();
 
-    /* 
+    /*
      * Populate sess with default host hash
      */
 
-    curr_host =
-        g_hash_table_lookup(ldminfo_hash,
-                            g_list_nth_data(host_list, current_host_id));
+    curr_host = ldminfo_lookup(g_list_nth_data(host_list, current_host_id));
 
     gtk_combo_box_append_text(GTK_COMBO_BOX(sess_select),
                               g_strdup(_("Default")));
